# <span class="badge package-core"></span> role

## Objects

 * <span class="badge object-type-class"></span> [Role](./object-Role.md)
## Builders

 * <span class="badge builder"></span> [Role](./builder-Role.md)
